==> kubernetes-model-1.0.37-sources.jar: annotations/io/fabric8/kubernetes/api/model/CapabilitiesFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.ArrayList;
import java.util.Map;
import java.util.HashMap;
import java.util.List;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class CapabilitiesFluentImpl<T extends CapabilitiesFluent<T>> extends BaseFluent<T> implements CapabilitiesFluent<T>{

     List<String> add = new ArrayList();     List<String> drop = new ArrayList();     Map<String, Object> additionalProperties = new HashMap();
public CapabilitiesFluentImpl(){
    
}
public CapabilitiesFluentImpl( Capabilities instance ){
    this.withAdd(instance.getAdd()); this.withDrop(instance.getDrop()); 
}

    public T addToAdd( String ...items){
    for (String item : items) {this.add.add(item);} return (T)this;
    }
    public T removeFromAdd( String ...items){
    for (String item : items) {this.add.remove(item);} return (T)this;
    }
    public List<String> getAdd(){
    return this.add;
    }
    public T withAdd( List<String> add){
    this.add.clear();if (add != null) {for (String item : add){this.addToAdd(item);}} return (T) this;
    }
    public T withAdd( String ...add){
    this.add.clear(); if (add != null) {for (String item :add){ this.addToAdd(item);}} return (T) this;
    }
    public T addToDrop( String ...items){
    for (String item : items) {this.drop.add(item);} return (T)this;
    }
    public T removeFromDrop( String ...items){
    for (String item : items) {this.drop.remove(item);} return (T)this;
    }
    public List<String> getDrop(){
    return this.drop;
    }
    public T withDrop( List<String> drop){
    this.drop.clear();if (drop != null) {for (String item : drop){this.addToDrop(item);}} return (T) this;
    }
    public T withDrop( String ...drop){
    this.drop.clear(); if (drop != null) {for (String item :drop){ this.addToDrop(item);}} return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
CapabilitiesFluentImpl that = (CapabilitiesFluentImpl) o;
if (add != null ? !add.equals(that.add) :that.add != null) return false;
if (drop != null ? !drop.equals(that.drop) :that.drop != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.51-sources.jar: annotations/io/fabric8/kubernetes/api/model/CapabilitiesFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.ArrayList;
import java.util.RandomAccess;
import java.util.Map;
import java.util.Map;
import java.util.List;
import java.util.List;
import java.util.AbstractCollection;
import java.util.AbstractList;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Collection;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;

public class CapabilitiesFluentImpl<T extends CapabilitiesFluent<T>> extends BaseFluent<T> implements CapabilitiesFluent<T>{

     List<String> add = new ArrayList();     List<String> drop = new ArrayList();     Map<String, Object> additionalProperties = new HashMap();
public CapabilitiesFluentImpl(){
    
}
public CapabilitiesFluentImpl( Capabilities instance ){
    this.withAdd(instance.getAdd()); this.withDrop(instance.getDrop()); 
}

    public T addToAdd( String ...items){
    for (String item : items) {this.add.add(item);} return (T)this;
    }
    public T removeFromAdd( String ...items){
    for (String item : items) {this.add.remove(item);} return (T)this;
    }
    public List<String> getAdd(){
    return this.add;
    }
    public T withAdd( List<String> add){
    this.add.clear();if (add != null) {for (String item : add){this.addToAdd(item);}} return (T) this;
    }
    public T withAdd( String ...add){
    this.add.clear(); if (add != null) {for (String item :add){ this.addToAdd(item);}} return (T) this;
    }
    public T addToDrop( String ...items){
    for (String item : items) {this.drop.add(item);} return (T)this;
    }
    public T removeFromDrop( String ...items){
    for (String item : items) {this.drop.remove(item);} return (T)this;
    }
    public List<String> getDrop(){
    return this.drop;
    }
    public T withDrop( List<String> drop){
    this.drop.clear();if (drop != null) {for (String item : drop){this.addToDrop(item);}} return (T) this;
    }
    public T withDrop( String ...drop){
    this.drop.clear(); if (drop != null) {for (String item :drop){ this.addToDrop(item);}} return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
CapabilitiesFluentImpl that = (CapabilitiesFluentImpl) o;
if (add != null ? !add.equals(that.add) :that.add != null) return false;
if (drop != null ? !drop.equals(that.drop) :that.drop != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
